==> renamer-3.0.0-5.tgz: package/README.md <==
[![view on npm](https://badgen.net/npm/v/renamer)](https://www.npmjs.org/package/renamer)
[![npm module downloads](https://badgen.net/npm/dt/renamer)](https://www.npmjs.org/package/renamer)
[![Gihub repo dependents](https://badgen.net/github/dependents-repo/75lb/renamer)](https://github.com/75lb/renamer/network/dependents?dependent_type=REPOSITORY)
[![Gihub package dependents](https://badgen.net/github/dependents-pkg/75lb/renamer)](https://github.com/75lb/renamer/network/dependents?dependent_type=PACKAGE)
[![Build Status](https://travis-ci.org/75lb/renamer.svg?branch=master)](https://travis-ci.org/75lb/renamer)
[![Coverage Status](https://coveralls.io/repos/github/75lb/renamer/badge.svg)](https://coveralls.io/github/75lb/renamer)
[![js-standard-style](https://img.shields.io/badge/code%20style-standard-brightgreen.svg)](https://github.com/feross/standard)

***Upgraders, please read the [release notes](https://github.com/75lb/renamer/releases). Please share feedback and improvement ideas [here](https://github.com/75lb/renamer/discussions).***

# renamer

Renamer is a command-line utility to help rename files and folders. It is flexible and extensible via plugins.

## Disclaimer

Always run this tool with the `--dry-run` option until you are confident the results look correct.

## Synopsis

_The examples below use double quotes to suit Windows users. MacOS & Linux users should use single quotes._


As input, renamer takes a list of filenames or glob patterns plus some options describing how you would like the files to be renamed.

```
$ renamer [options] [file...]
```

This trivial example will replace the text `jpeg` with `jpg` in all file and directory names in the current directory.

```
$ renamer --find jpeg --replace jpg *
```

As above but operates on all files and folders recursively.

```
$ renamer --find jpeg --replace jpg "**"
```

### Custom file list

If no filenames or patterns are specified, renamer will look for a newline-separated list of filenames on standard input. This approach is useful for crafting a specific input list using tools like `find`. This example operates on files modified less than 20 minutes ago.

```
$ find . -mtime -20m | renamer --find jpeg --replace jpg
```

Same again but with a hand-rolled input of filenames and glob patterns. Create an input text file, e.g. `files.txt`:

```
house.jpeg
garden.jpeg
img/*
```

Then pipe it into renamer.

```
$ cat files.txt | renamer --find jpeg --replace jpg
```

### Replace regular expression patterns

Simple example using a [regular expression literal](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions). The case-insensitive pattern `/one/i` matches the input file `ONE.jpg`, renaming it to `two.jpg`.

```
$ renamer --find "/one/i" --replace "two" ONE.jpg
```

### Rename using JavaScript

For more complex renames. Define a plugin.

```js
class AddMonth {
  replace (filePath) {
    const month = new Intl.DateTimeFormat('en-gb', { month: 'long' }).format(new Date())
    return filePath.replace(/^/, `[${month}] `)
  }
}

export default AddMonth
```

Invoke a custom replace chain using the plugin.

```
$ renamer --chain add-month.mjs * -d

Dry run

✔︎ pic1.jpg → [April] pic1.jpg
✔︎ pic2.jpg → [April] pic2.jpg

Rename complete: 2 of 6 files renamed.
```

## Views



## Further reading

Please see [the wiki](https://github.com/75lb/renamer/wiki) for

* [Usage examples](https://github.com/75lb/renamer/wiki/examples).
*  More information about [using plugins](https://github.com/75lb/renamer/wiki/How-to-use-renamer-plugins) and [writing plugins](https://github.com/75lb/renamer/wiki/How-to-write-a-renamer-plugin).
* The [full list of command-line options](https://github.com/75lb/renamer/wiki/Renamer-CLI-docs).

For more information on Regular Expressions, see [this useful guide](https://developer.mozilla.org/en/docs/Web/JavaScript/Guide/Regular_Expressions).

## Install

```
$ npm install -g renamer
```

* * *

&copy; 2012-21 Lloyd Brookes \<75pound@gmail.com\>.

Tested by [test-runner](https://github.com/test-runner-js/test-runner). Documented by [jsdoc-to-markdown](https://github.com/75lb/jsdoc-to-markdown).

==> renamer-3.0.0-6.tgz: package/README.md <==
[![view on npm](https://badgen.net/npm/v/renamer)](https://www.npmjs.org/package/renamer)
[![npm module downloads](https://badgen.net/npm/dt/renamer)](https://www.npmjs.org/package/renamer)
[![Gihub repo dependents](https://badgen.net/github/dependents-repo/75lb/renamer)](https://github.com/75lb/renamer/network/dependents?dependent_type=REPOSITORY)
[![Gihub package dependents](https://badgen.net/github/dependents-pkg/75lb/renamer)](https://github.com/75lb/renamer/network/dependents?dependent_type=PACKAGE)
[![Build Status](https://travis-ci.org/75lb/renamer.svg?branch=master)](https://travis-ci.org/75lb/renamer)
[![Coverage Status](https://coveralls.io/repos/github/75lb/renamer/badge.svg)](https://coveralls.io/github/75lb/renamer)
[![js-standard-style](https://img.shields.io/badge/code%20style-standard-brightgreen.svg)](https://github.com/feross/standard)

***Upgraders, please read the [release notes](https://github.com/75lb/renamer/releases). Please share feedback and improvement ideas [here](https://github.com/75lb/renamer/discussions).***

# renamer

Renamer is a command-line utility to help rename files and folders. It is flexible and extensible via plugins.

## Disclaimer

Always run this tool with the `--dry-run` option until you are confident the results look correct.

## Synopsis

_The examples below use double quotes to suit Windows users. MacOS & Linux users should use single quotes._


As input, renamer takes a list of filenames or glob patterns plus some options describing how you would like the files to be renamed.

```
$ renamer [options] [file...]
```

This trivial example will replace the text `jpeg` with `jpg` in all file and directory names in the current directory.

```
$ renamer --find jpeg --replace jpg *
```

As above but operates on all files and folders recursively.

```
$ renamer --find jpeg --replace jpg "**"
```

### Fine-tune which files to process

If no filenames or patterns are specified, renamer will look for a newline-separated list of filenames on standard input. This approach is useful for crafting a specific input list using tools like `find`. This example operates on files modified less than 20 minutes ago.

```
$ find . -mtime -20m | renamer --find jpeg --replace jpg
```

Same again but with a hand-rolled input of filenames and glob patterns. Create an input text file, e.g. `files.txt`:

```
house.jpeg
garden.jpeg
img/*
```

Then pipe it into renamer.

```
$ cat files.txt | renamer --find jpeg --replace jpg
```

### Rename using regular expressions

Simple example using a [regular expression literal](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions). The case-insensitive pattern `/one/i` matches the input file `ONE.jpg`, renaming it to `two.jpg`.

```
$ renamer --find "/one/i" --replace "two" ONE.jpg
```

### Rename using JavaScript

For more complex renames, or if you just prefer using code, you can write a replace function. Create a module exporting a class which defines a `replace` method. This trivial example appends the text `[DONE]` to each file name.

```js
import path from 'path'

class Suffix {
  replace (filePath) {
    const file = path.parse(filePath)
    const newName = file.name + ' [DONE]' + file.ext
    return path.join(file.dir, newName)
  }
}

export default Suffix
```

Process all files in the current directory using your plugin as the replace chain.

```
$ renamer --dry-run --chain suffix.mjs *

Dry run

✔︎ pic1.jpg → pic1 [DONE].jpg
✔︎ pic2.jpg → pic2 [DONE].jpg

Rename complete: 2 of 6 files renamed.
```

## Views

Use the default view, a built-in alternative (long, diff, one-line) or a custom view.

<img src="https://i.imgur.com/7830Y9N.gif" width="620px" title="Renamer views demo">

## Further reading

Please see [the wiki](https://github.com/75lb/renamer/wiki) for

* [Usage examples](https://github.com/75lb/renamer/wiki/examples).
*  More information about [using plugins](https://github.com/75lb/renamer/wiki/How-to-use-renamer-plugins) and [writing plugins](https://github.com/75lb/renamer/wiki/How-to-write-a-renamer-plugin).
* The [full list of command-line options](https://github.com/75lb/renamer/wiki/Renamer-CLI-docs).

For more information on Regular Expressions, see [this useful guide](https://developer.mozilla.org/en/docs/Web/JavaScript/Guide/Regular_Expressions).

## Install

```
$ npm install -g renamer
```

* * *

&copy; 2012-21 Lloyd Brookes \<75pound@gmail.com\>.

Tested by [test-runner](https://github.com/test-runner-js/test-runner). Documented by [jsdoc-to-markdown](https://github.com/75lb/jsdoc-to-markdown).
